@@ -23,9 +23,7 @@
 
 #--------------------------------------------------------------------------------------
 """
-Cleans all the "''file''" related information from ''cloud''. 
-It works like shutdown for the ''cloud'' data storage functionality. 
-Use this functionality with precautions.
+Cleans all nodes from cloudservers and cloudfiles that correspond to defined rackspace account
 """
 
 #--------------------------------------------------------------------------------------
@@ -55,6 +53,8 @@ def main() :
     #----------------------- Definition of the command line arguments ------------------------
     common.concurrency_options.add( an_option_parser )
 
+    common.communication_options.add( an_option_parser )
+
     amazon.security_options.add( an_option_parser )
     
     common.options.add( an_option_parser )
@@ -65,6 +65,8 @@ def main() :
 
     common.options.extract( an_option_parser )
     
+    common.communication_options.extract( an_option_parser )
+
     a_number_threads = common.concurrency_options.extract( an_option_parser )
     
     AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.security_options.extract( an_option_parser )
