@@ -29,7 +29,8 @@ This script is responsible for cluster environment setup for the given Amazon EC
 
 #--------------------------------------------------------------------------------------
 import cloudflu.common as common
-from cloudflu.common import print_d, print_e, sh_command, Timer
+from cloudflu.common import print_d, print_e
+from cloudflu.common import Timer, sh_command
 from cloudflu.common import ssh
 
 from cloudflu import amazon
@@ -92,7 +93,7 @@ def main() :
 
     an_upload_seed_size = data_seeding_options.extract( an_option_parser )
 
-    a_case_dir, a_run_hook = solver_start_options.extract( an_option_parser )
+    a_case_dir, a_run_hook, a_wait_run = solver_start_options.extract( an_option_parser )
 
     a_study_name = data_transfer_options.extract( an_option_parser )
     
@@ -108,7 +109,7 @@ def main() :
     a_call = "%s %s %s %s %s" % ( an_engine,
                                   ec2.use.options.compose( a_cluster_id ),
                                   data_transfer_options.compose( a_study_name ), 
-                                  solver_start_options.compose( a_case_dir, a_run_hook ),
+                                  solver_start_options.compose( a_case_dir, a_run_hook, a_wait_run ),
                                   openmpi_config_options.compose( a_hostfile ) )
     print_d( a_call + '\n' )
 
@@ -181,15 +182,27 @@ def main() :
 
     a_target_dir = os.path.join( a_working_dir, a_case_name )
 
-    an_additional_args = "--study-name='%s' --booked --upload-seed-size=%d" % ( a_study_name, an_upload_seed_size )
+    an_additional_args = "--booked"
+    an_additional_args += " --study-name='%s'" % ( a_study_name )
+    an_additional_args += " --upload-seed-size=%d" % ( an_upload_seed_size )
 
-    a_ssh_client = an_instance2ssh[ a_master_node ]
-    ssh.command( a_ssh_client, "%s/%s %d '%s' %s" % ( a_target_dir, a_run_hook, a_num_nodes, a_hostfile, an_additional_args ) )
+    a_command = "%s/%s %d '%s' %s" % ( a_target_dir, a_run_hook, a_num_nodes, a_hostfile, an_additional_args )
 
-    an_output_study.seal()
+    if a_wait_run == False :
+        a_host_name = a_master_node.public_dns_name
+        a_ssh = ssh.options.command( a_password, an_identity_file, a_host_port, a_login_name, a_host_name )
+        a_ssh += ' -n -f "source /etc/profile && nohup %s > /dev/null 2>&1 &"' % a_command
+        print_d( '%s\n' % a_ssh )
 
-    [ a_ssh_client.close() for a_ssh_client in an_instance2ssh.values() ]
+        import os; os.system( a_ssh )
+    else:
+        a_ssh_client = an_instance2ssh[ a_master_node ]
+
+        ssh.command( a_ssh_client, a_command )
+        pass
     
+    [ a_ssh_client.close() for a_ssh_client in an_instance2ssh.values() ]
+
     print_d( "a_spent_time = %s, sec\n" % a_spent_time )
     
 
