@@ -118,14 +118,15 @@ def main() :
     
     a_booked = data_upload_options.extract( an_option_parser )
 
-    a_solver_run, a_case_dir, a_solver_log, a_watched_keyword, a_time_log = timestamps_upload_options.extract( an_option_parser )
+    a_solver_run, a_case_dir, a_solver_log, a_watched_keyword, a_time_log, a_finish_hook = \
+        timestamps_upload_options.extract( an_option_parser )
     
 
     print_d( "\n--------------------------- Canonical substitution ------------------------\n" )
     import sys; an_engine = sys.argv[ 0 ]
 
     a_call = "%s %s %s %s %s" % ( an_engine, 
-                                  timestamps_upload_options.compose( a_solver_run, a_case_dir, a_solver_log, a_watched_keyword, a_time_log ),
+                                  timestamps_upload_options.compose( a_solver_run, a_case_dir, a_solver_log, a_watched_keyword, a_time_log, a_finish_hook ),
                                   data_upload_options.compose( a_booked ),
                                   study_book_options.compose( a_study_name ),
                                   data_seeding_options.compose( an_upload_seed_size ) )
@@ -186,6 +187,24 @@ def main() :
     a_worker_pool.shutdown()
     a_worker_pool.join()
 
+
+    print_d( "\n------------------------ Running timestamps hook --------------------------\n" )
+    an_additional_args = "--study-name='%s'" % ( a_study_name )
+    an_additional_args += " --number-threads=%d" % ( a_number_threads )
+    an_additional_args += " --upload-seed-size=%d" % ( an_upload_seed_size )
+
+    if a_booked == True :
+        an_additional_args += " --booked"
+        pass
+
+    sh_command( "%s %s" % ( a_finish_hook, an_additional_args ) )
+
+
+    print_d( "\n------------------------ Sealing the given study --------------------------\n" )
+    an_additional_args = "--study-name='%s'" % ( a_study_name )
+    sh_command( "cloudflu-study-seal %s" % ( an_additional_args ) )
+
+
     print_d( "a_spent_time = %s, sec\n" % a_spent_time )
 
 
