@@ -23,8 +23,7 @@
 
 #------------------------------------------------------------------------------------------
 """
-Prepares specified set of data and registers them for uploading into ''study''. 
-This is the first step for macro ''[[cloudflu-study-upload]]'' utility.
+This script is responsible for efficient uploading of multi file data
 """
 
 
@@ -55,14 +54,8 @@ def upload_file( the_worker_pool, the_file_path, the_file_location, the_study_ob
     import tempfile
     a_tmp_file = tempfile.mkstemp( dir = a_working_dir )[ 1 ]
     # a_tmp_file = tempfile.mkstemp()[ 1 ] # use this work arround for FAT file systems
-    
-    from cloudflu.common.archivators import get_archivator
-    an_api_version = the_study_object.api_version()
-    an_archivator = get_archivator( an_api_version )
-    
-    an_archivator.pack( a_file_dirname, a_tmp_file, a_file_basename, the_printing_depth )
-#    sh_command( "cd '%s' &&  tar -czf %s '%s'" % 
-#                ( a_file_dirname, a_tmp_file, a_file_basename ), the_printing_depth )
+    sh_command( "cd '%s' &&  tar -czf %s '%s'" % 
+                ( a_file_dirname, a_tmp_file, a_file_basename ), the_printing_depth )
 
     a_statinfo = os.stat( a_tmp_file )
     print_d( "a_statinfo.st_size = %d, bytes\n" % a_statinfo.st_size, the_printing_depth )
@@ -77,8 +70,8 @@ def upload_file( the_worker_pool, the_file_path, the_file_location, the_study_ob
     print_d( "a_suffix_length = %d, digits\n" % a_suffix_length, the_printing_depth )
 
     a_file_seed_target = os.path.join( a_working_dir, a_file_basename )
-    sh_command( "cat '%s' | split --bytes=%d --numeric-suffixes --suffix-length=%d - %s.%s-" % 
-                ( a_tmp_file, the_upload_seed_size, a_suffix_length, a_file_seed_target, an_archivator.suffix() ), the_printing_depth )
+    sh_command( "cat '%s' | split --bytes=%d --numeric-suffixes --suffix-length=%d - %s.tgz-" % 
+                ( a_tmp_file, the_upload_seed_size, a_suffix_length, a_file_seed_target ), the_printing_depth )
 
     a_file_pointer = open( a_tmp_file, 'rb' )
     a_md5 = compute_md5( a_file_pointer )
@@ -150,6 +143,8 @@ def main() :
 
     common.concurrency_options.add( an_option_parser )
 
+    common.communication_options.add( an_option_parser )
+
     amazon.security_options.add( an_option_parser )
     
     common.options.add( an_option_parser )
@@ -162,6 +157,8 @@ def main() :
     
     AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.security_options.extract( an_option_parser )
     
+    common.communication_options.extract( an_option_parser )
+
     a_number_threads = common.concurrency_options.extract( an_option_parser )
     
     an_upload_seed_size = data_seeding_options.extract( an_option_parser )
