@@ -135,7 +135,7 @@ def sh_command( the_command, the_printing_depth = 0 ) :
     for a_line in a_stdout_lines : print_d( "\t%s" % a_line )
 
     if a_return_code != 0 :
-        raise OSError( a_return_code, '\n'.join(a_stderr_lines), "(%s)\n" % the_command )
+        raise OSError( "(%s)\n" % the_command )
         pass
     
     return a_stdout_lines
@@ -196,36 +196,27 @@ class WorkerPool( workerpool.WorkerPool ) :
         workerpool.WorkerPool.__init__( self, size, maxjobs, worker_factory )
 
         from workerpool.pools import Queue
-        self._results = Queue()
+        self.results = Queue()
         pass
 
     def charge( self, the_function, *the_args ) :
         "Perform a map operation distributed among the workers. Will block until done."
         from workerpool import SimpleJob
-        self.put( SimpleJob( self._results, the_function, *the_args ) )
+        self.put( SimpleJob( self.results, the_function, *the_args ) )
 
         pass
 
     def is_all_right( self ) :
-        a_results = self.get_results()
-        a_count_false = a_results.count( False )
-        
-        if a_count_false > 0:
-           return False
-
-        return True
-    
-    def get_results( self ):
         self.join()
 
-        a_results = list()
-        for i in range( self._results.qsize() ):
-            a_results.append( self._results.get() )
-            self._results.task_done()
+        a_result = True
+        for i in range( self.results.qsize() ):
+            a_result &= self.results.get()
+            self.results.task_done()
             pass
 
-        return a_results
-        
+        return a_result
+
     pass
 
 
