@@ -46,14 +46,14 @@ a_container = OptionGroup( 'common.ssh.run' )
 
 import cloudflu.common as common
 a_container.add_option( TransientOption( "--script-file",
-                                         metavar = "< script (or list of scripts separated by '%s' )"
+                                         metavar = "< script (or list of scripts separated by '%s')"
                                          "or be executed on the remote host >" % common.arg_list_separator(),
                                          action = "store",
                                          dest = "script_file",
                                          default = None ) )
 
 a_container.add_option( TransientOption( "--script-args",
-                                         metavar = "< arguments (or list of arguments separated by '%s' )"
+                                         metavar = "< arguments (or list of arguments separated by '%s)"
                                          "or the remote script execution >" % common.arg_list_separator(),
                                          action = "store",
                                          dest = "script_args",
@@ -80,7 +80,7 @@ def extract( the_option_parser ) :
         a_scripts = a_script_file.split( common.arg_list_separator() )
         for a_script in a_scripts :
             if not os.path.isfile( a_script ) :
-                the_option_parser.error( "--script-file='%s' must be a file" % a_script )
+                an_option_parser.error( "--script-file='%s' must be a file" % a_script )
                 pass
             pass
 
