@@ -21,11 +21,6 @@
 ##
 
 
-#--------------------------------------------------------------------------------------
-import cloudflu.common as common
-from cloudflu.common import print_d, print_e
-
-
 #--------------------------------------------------------------------------------------
 def create_test_file( the_size ) :
     import tempfile
@@ -47,23 +42,12 @@ def delete_object( the_object ):
        except:
          pass 
     pass
-
-
-#--------------------------------------------------------------------------------------
-def calculate_speed( the_size, the_time ):
-    import sys
-    if the_time < 0:
-       return 0
-       
-    a_speed = ( float( the_size * 8 ) / the_time ) / 1024
-
-    return a_speed
-
+    
 
 #--------------------------------------------------------------------------------------
 class SeedSizeMesurement :
     #------------------------------------------------------------------------------------
-    def __init__( self, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, the_region, the_number_threads, the_initial_size = 8192 ) :
+    def __init__( self, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, the_region, the_initial_size = 8192 ) :
         #---------------------------- Adjust 'boto' functionality -----------------------------
         import ConfigParser
         a_config_parser = ConfigParser.SafeConfigParser()
@@ -80,174 +64,78 @@ class SeedSizeMesurement :
         os.environ[ 'BOTO_CONFIG' ] = self._config_file
 
         #------------------------------ Create a testing bucket -------------------------------
-        self._bucket = create_testing_bucket( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, the_region  )
+        from boto.s3.connection import S3Connection
+        self._conn = S3Connection( aws_access_key_id = AWS_ACCESS_KEY_ID, 
+                                   aws_secret_access_key = AWS_SECRET_ACCESS_KEY )
+        import uuid
+        a_backet_name = "config-" + str( uuid.uuid4() )
+        self._backet = self._conn.create_bucket( a_backet_name, location = the_region )
+
 
         #---------------------------- Estimate the timeout value ------------------------------
-        self._timeout = measure_time( self._bucket, the_initial_size )
-        print_d( "timeout (true) = %3.2f, sec\n" % ( self._timeout ) )
+        a_filesize = the_initial_size
+        a_filename = create_test_file( a_filesize )
+        
+        from boto.s3.key import Key    
+        a_key = Key( self._backet, a_filename )
 
-        self.set_number_threads( the_number_threads )
+        import time
+        a_start_time = time.time()
+        a_key.set_contents_from_filename( a_filename )
+        a_end_time = time.time()
+        self._timeout = a_end_time - a_start_time
+        print "timeout = %3.2f sec" % ( self._timeout )
+
+        import socket
+        socket.setdefaulttimeout( self._timeout )
+
+        delete_object( a_key )
+        import os; os.remove( a_filename )
         pass
 
 
     #------------------------------------------------------------------------------------
     def timeout( self ):
-        return self._timeout
+        return self._timeout + 1.0
 
 
-    #------------------------------------------------------------------------------------
-    def set_number_threads( self, the_value ):
-        self._number_threads = the_value
-        a_timeout = self._timeout * self._number_threads
-        print_d( "timeout (efficient) = %3.2f, sec\n" % ( a_timeout ) )
-
-        import socket
-        socket.setdefaulttimeout( a_timeout )
-        
-        pass
-    
-    #------------------------------------------------------------------------------------
-    def number_threads( self ):
-        return self._number_threads
-    
     #------------------------------------------------------------------------------------
     def __call__( self, the_filesize ):
-      if self._number_threads == 1:
-         a_time = measure_time( self._bucket, the_filesize )
-         a_speed = calculate_speed( the_filesize, a_time )
-         return a_speed
-      
-      
-      from cloudflu.common import WorkerPool
-      import time
-      a_start_time = time.time()
+      a_filename = create_test_file( the_filesize )
 
-      a_worker_pool = WorkerPool( self._number_threads )
-      for i in range( self._number_threads ):
-          a_worker_pool.charge( measure_time, ( self._bucket, the_filesize ) )
-          pass
-      
-      a_times = a_worker_pool.get_results()
-      a_worker_pool.shutdown()
+      from boto.s3.key import Key
+      a_key_name = 'test_' + str( the_filesize )
+      a_key = Key( self._backet, a_filename )
 
-      an_end_time = time.time()
-      a_time = an_end_time - a_start_time
-      a_speeds = list()
-      a_string = ''
-      for time in a_times:
-          a_speed = calculate_speed( the_filesize, time )
-          a_speeds.append( a_speed )
-          a_string += " %4.2f " % time
+      a_speed = 0
+      try:
+          import time
+          a_start_time = time.time()
+          a_key.set_contents_from_filename( a_filename )
+          a_end_time = time.time()
+          
+          delete_object( a_key )
+
+          a_time = a_end_time - a_start_time
+          a_speed = ( float( the_filesize * 8 ) / a_time ) / 1024          
+      except Exception, exc:
+          delete_object( a_key )
           pass
-      
-      a_count_non_zero = self._number_threads - a_speeds.count( 0 )
-      a_speed = ( ( float( a_count_non_zero ) * the_filesize * 8 ) / float( a_time ) ) / 1024
-      print_d( "%4d - {%s} : %4.2f = %4.2f\n" % ( the_filesize, a_string, a_time, a_speed ) )
-      
+
+      import os; os.remove( a_filename )
+
       return a_speed
-      
+    
     
     #------------------------------------------------------------------------------------
     def __del__( self ) :
         import os; os.remove( self._config_file )
-        delete_object( self._bucket )
-        #print '__del__'
+        delete_object( self._backet )
+        print '__del__'
         pass
     pass
 
 
-#--------------------------------------------------------------------------------------
-def create_testing_bucket( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, the_region  ): 
-    from boto.s3.connection import S3Connection
-    a_conn = S3Connection( aws_access_key_id = AWS_ACCESS_KEY_ID, 
-                           aws_secret_access_key = AWS_SECRET_ACCESS_KEY )
-    import uuid
-    a_bucket_name = "config-" + str( uuid.uuid4() )
-    a_bucket = a_conn.create_bucket( a_bucket_name, location = the_region )
-    
-    return a_bucket
-
-
-#--------------------------------------------------------------------------------------
-def measure_time( the_bucket, the_filesize ):
-    a_filename = create_test_file( the_filesize )
-
-    from boto.s3.key import Key
-    a_key_name = 'test_' + str( the_filesize )
-    a_key = Key( the_bucket, a_filename )
-
-    a_speed = 0
-    import sys; a_time = -1.0
-    try:
-        import time
-        a_start_time = time.time()
-        a_key.set_contents_from_filename( a_filename )
-        a_end_time = time.time()
-         
-        delete_object( a_key )
-        a_time = a_end_time - a_start_time
-
-    except Exception, exc:
-        delete_object( a_key )
-        pass
-    
-    return a_time
-    
-
-#--------------------------------------------------------------------------------------
-def search_best_region( the_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY ):
-    print_d( "looking for \"best\" region ...\n" )
-    a_regions = [ '', 'EU', 'ap-southeast-1', 'us-west-1' ]
-    
-    a_test_filesize = 8192
-    
-    # Prepare buckets in different regions and dictionary for speed values 
-    a_region2bucket = {}
-    a_region2speeds = {}    
-    a_region2sum_speeds= {}
-    for a_region in a_regions:
-        a_region2bucket[ a_region ] = create_testing_bucket( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, a_region  )
-        a_region2speeds[ a_region ] = list()
-        a_region2sum_speeds[ a_region ] = 0
-        pass
-    
-    for i in range( the_nb_attempts ):
-        for a_region in a_regions:
-            a_time = measure_time( a_region2bucket[ a_region ], a_test_filesize )
-            a_speed  = calculate_speed( a_test_filesize, a_time )
-            a_region2speeds[ a_region ].append( a_speed )
-            a_region2sum_speeds[ a_region ] = a_region2sum_speeds[ a_region ] + a_speed
-            pass
-        pass    
-    
-    # Calculate average speed in each region and delete buckets
-    average_speed2region = {}
-    for a_region in a_regions:
-        an_averagespeed = a_region2sum_speeds[ a_region ] / float( the_nb_attempts )
-        average_speed2region[ an_averagespeed ] = a_region
-        print_d( " region \'%s\' : %4.0f, kbs\n"  % ( a_region, an_averagespeed ) )
-        delete_object( a_region2bucket[ a_region ] ) 
-        pass
-    
-    an_average_speeds = average_speed2region.keys()
-    an_average_speeds.sort(); an_average_speeds.reverse()
-    a_best_average_speed = an_average_speeds[ 0 ]
-    
-    a_best_region = average_speed2region[ a_best_average_speed ]
-    
-    a_full_name = a_best_region
-    if a_best_region == '':
-       a_full_name = "us-east-1 ( \'\' )"
-       pass
-    
-    print_d( "\nfastest region - \"%s\"\n\n" % a_full_name )
-
-    a_first_stats = {}
-    a_first_stats[ a_test_filesize ] = a_region2speeds[ a_region ] # further, we use this values
-    
-    return a_best_region, a_first_stats 
-
-
 #--------------------------------------------------------------------------------------
 class TFilterFunctor :
     def __init__( self, the_start, the_end, the_precision = 1.0E-8 ) :
@@ -262,23 +150,12 @@ class TFilterFunctor :
     pass
 
 
-#--------------------------------------------------------------------------------------
-def create_values_string( the_values ) :
-    a_string = ''
-    for a_value in the_values:
-        a_string +=  "%4.2f, " % a_value
-        pass
-
-    return a_string[ : -2 ] # remove last ", "
-
-
 #--------------------------------------------------------------------------------------
 def print_dict( the_x2y ) :
     a_xs = the_x2y.keys()
     a_xs.sort()
     for a_x in a_xs :
-        a_values_string = create_values_string( the_x2y[ a_x ] )
-        print_d( "%4d : %s\n" % ( a_x, a_values_string ) )
+        print "%4d : %4.0f" % ( a_x, the_x2y[ a_x ] )
         pass
     pass
 
@@ -292,38 +169,16 @@ def print2_dict( the_sub_xs, the_x2y ) :
     a_xs.sort()
     for a_x in a_xs :
         if a_x in the_sub_xs :
-            print_d( " + " )
+            print " + ", 
         else:
-            print_d( " - " )
+            print " - ", 
             pass
-
-        a_values_string = create_values_string( the_x2y[ a_x ] )
-        print_d( "%4d : %s\n" % ( a_x, a_values_string ) )
-
+        print "%4d : %4.0f" % ( a_x, the_x2y[ a_x ] )
         a_counter += 1
         pass
     pass
 
 
-#--------------------------------------------------------------------------------------
-def arithmetic_average( the_values ):
-    a_size = len( the_values )
-    a_summ = 0
-    for a_value in the_values:
-        a_summ += a_value
-        pass
-
-    an_arithmetic_average = a_summ / float( a_size )
-
-    return an_arithmetic_average
-    
-    
-#--------------------------------------------------------------------------------------
-def get_y( the_x2y ):
-    
-    return arithmetic_average( the_x2y )
-
-
 #--------------------------------------------------------------------------------------
 def find_center( the_x2y, the_sub2_nb_attempts ) :
     an_average_y = {}
@@ -333,16 +188,17 @@ def find_center( the_x2y, the_sub2_nb_attempts ) :
 
     a_xs.sort()
     for an_id in range( a_nb_attempts ) :
-        a_center_x = a_xs[ an_id ]
+        a_center_x = a_x = a_xs[ an_id ]
+        an_y = the_x2y[ a_x ]
+
         a_neighbor_nb_attemps = 0
-        an_y = 0.0
 
         # print "[", 
         if an_id < the_sub2_nb_attempts :
             a_neighbor_nb_attemps += an_id
             for a_sub_id in range( an_id ) :
                 a_x = a_xs[ a_sub_id ]
-                an_y += get_y( the_x2y[ a_x ] )
+                an_y += the_x2y[ a_x ]
                 # print "%4d" % a_x,
                 pass
             pass
@@ -350,7 +206,7 @@ def find_center( the_x2y, the_sub2_nb_attempts ) :
             a_neighbor_nb_attemps += the_sub2_nb_attempts
             for a_sub_id in range( an_id - the_sub2_nb_attempts, an_id ) :
                 a_x = a_xs[ a_sub_id ]
-                an_y += get_y( the_x2y[ a_x ] )
+                an_y += the_x2y[ a_x ]
                 # print "%4d" % a_x,
                 pass
             pass
@@ -361,7 +217,7 @@ def find_center( the_x2y, the_sub2_nb_attempts ) :
             a_neighbor_nb_attemps += a_nb_attempts - an_id
             for a_sub_id in range( an_id, a_nb_attempts ) :
                 a_x = a_xs[ a_sub_id ]
-                an_y += get_y( the_x2y[ a_x ] )
+                an_y += the_x2y[ a_x ]
                 # print "%4d" % a_x,
                 pass
             pass
@@ -369,12 +225,12 @@ def find_center( the_x2y, the_sub2_nb_attempts ) :
             a_neighbor_nb_attemps += the_sub2_nb_attempts
             for a_sub_id in range( an_id, an_id + the_sub2_nb_attempts ) :
                 a_x = a_xs[ a_sub_id ]
-                an_y += get_y( the_x2y[ a_x ] )
+                an_y += the_x2y[ a_x ]
                 # print "%4d" % a_x, 
                 pass
             pass
         an_average_y[ a_center_x ] = an_y / a_neighbor_nb_attemps
-        # print "] = %4d x %d" % ( an_average_y[ a_center_x ], a_neighbor_nb_attemps )
+        # print "] = %4d" % an_average_y[ a_center_x ]
 
         pass
 
@@ -394,20 +250,31 @@ def find_center( the_x2y, the_sub2_nb_attempts ) :
         pass
 
     a_center_x = a_xs[ an_average_y_index ]
-    print_d( "center : [ %4d ] = %4d\n\n" % ( a_center_x, a_max_average_y ) )
+
+    #------------------------------------------------------------------------------------------
+    # Shift the 'center' to avoid mesurement of the same points
+    if an_average_y_index == 0 :
+        a_center_x -= ( a_xs[ an_average_y_index + 1 ] - a_xs[ an_average_y_index ] ) / 3.0
+    elif an_average_y_index == a_nb_attempts - 1 :
+        a_center_x += ( a_xs[ an_average_y_index ] - a_xs[ an_average_y_index - 1 ] ) / 3.0
+    else:
+        a_left_x = a_xs[ an_average_y_index - 1 ]
+        a_right_x = a_xs[ an_average_y_index + 1 ]
+        if an_average_y[ a_left_x ] < an_average_y[ a_right_x ] :
+            a_center_x += ( a_right_x - a_center_x ) / 3.0
+        else:
+            a_center_x -= ( a_center_x - a_left_x ) / 3.0
+            pass
+        pass
+
+    print "center: %4d - < value >: %4d\n" % ( a_center_x, a_max_average_y )    
     
     return a_center_x, a_max_average_y
 
 
 #--------------------------------------------------------------------------------------
 def update_x2y( the_fun, the_x2y, the_x ) :
-    an_y = the_fun( the_x )
-    try:
-        the_x2y[ the_x ].append( an_y )
-        pass
-    except:
-        the_x2y[ the_x ] = [ an_y ]
-        pass
+    the_x2y[ the_x ] = the_fun( the_x )
     pass
 
 
@@ -423,59 +290,28 @@ def get_stats( the_fun, the_x2y, the_cost, the_center_x, the_region_x, the_nb_at
         an_area = an_end_x - a_start_x
         pass
 
-    print_d( "[ %4d - %4d ] :\n" % ( a_start_x, an_end_x ) )
+    print "[ %4d - %4d ] : " % ( a_start_x, an_end_x )
 
     a_sub_xs = []
     a_x = an_end_x
     a_step = an_area / float( the_nb_attempts )
     for an_id in range( the_nb_attempts + 1 ) :
-        update_x2y( the_fun, the_x2y, a_x )
-        a_sub_xs.append( a_x )
-        the_cost += a_x * the_fun.number_threads()
+        if not the_x2y.has_key( a_x ) : 
+            update_x2y( the_fun, the_x2y, a_x )
+            a_sub_xs.append( a_x )
+            the_cost += a_x
+            pass
         a_x -= a_step
         pass
 
     print2_dict( a_sub_xs, the_x2y )
-    print_d( "cost : %4d\n\n" % the_cost )
+    print "cost : %4d\n" % the_cost
 
     return the_x2y, the_cost, an_area
 
 
 #--------------------------------------------------------------------------------------
-def calculate_optimal_number_threads( the_fun, the_seed_size, the_precision, the_nb_attempts ):
-    a_precision = float( the_precision / 100.0 )
-    a_nb_threads = a_start_nb_threads = the_fun.number_threads()
-    a_start_speed = 0.0
-    a_cost = 0
-    while True:
-        print_d( "number threads : %d\n" % a_nb_threads )
-        the_fun.set_number_threads( a_nb_threads )
-        a_speed = 0.0
-        for an_attempt in range( the_nb_attempts ) :
-            a_speed += the_fun( the_seed_size )
-            a_cost += the_seed_size * a_nb_threads
-            pass
-        
-        a_speed /= float( the_nb_attempts )
-        print_d( "speed : %4d\n\n" % a_speed )
-
-        import math
-        if a_speed < a_start_speed or math.fabs( a_speed - a_start_speed ) / a_speed < a_precision:
-            an_optimize_nb_threads = a_start_nb_threads
-            break
-
-        a_start_speed = a_speed
-        a_start_nb_threads = a_nb_threads
-        a_nb_threads += 1
-        pass
-    
-    the_fun.set_number_threads( an_optimize_nb_threads )
-    
-    return a_cost
-
-
-#--------------------------------------------------------------------------------------
-def calculate_optimal_seed_size( the_fun, the_center_x, the_region_x, the_precision, the_nb_attempts, the_x2y, the_get_stats = get_stats ) :
+def entry_point( the_fun, the_center_x, the_region_x, the_precision, the_nb_attempts, the_get_stats = get_stats ) :
     """The idea of this algorithm is very close to the 'interval' one; it supposes that the best value of a 
     probabilty nature function - F( x ) had better be defined through a some 'neighborhood', which could give
     more realistic representation of what is happenning in fact, not a precise point.
@@ -507,10 +343,10 @@ def calculate_optimal_seed_size( the_fun, the_center_x, the_region_x, the_precis
     like a dog; you need to give him a good hook first to make sure that he understood what you are looking for ).
     """
     a_center_x = the_center_x
-    print_d( "%4d - %4d\n\n" % ( a_center_x, 0.0 ) )
+    print "%4d - %4d\n" % ( a_center_x, 0.0 )
     a_sub_nb_attempts = the_nb_attempts / 1
     a_cost = 0.0
-    a_x2y = the_x2y
+    a_x2y = {}
 
     #------------------------------------------------------------------------------------------
     a_max_average_y = 0.0
@@ -537,30 +373,11 @@ def calculate_optimal_seed_size( the_fun, the_center_x, the_region_x, the_precis
 
     #------------------------------------------------------------------------------------------
     an_optimize_x = a_center_x
-    print_d( "solution : %4d / cost : %4d\n\n" % ( an_optimize_x, a_cost ) )
+    print "solution : %4d / cost : %4d\n" % ( an_optimize_x, a_cost )
 
     return an_optimize_x, a_cost
 
 
-#--------------------------------------------------------------------------------------
-def entry_point( the_fun, the_center_x, the_region_x, the_precision, the_nb_attempts, the_x2y, the_get_stats = get_stats ) :
-    a_precision = the_precision * 3.0
-    an_old_number_threads = the_fun.number_threads()
-    a_cost = 0
-    a_seed_size, a_cost = calculate_optimal_seed_size( the_fun, the_center_x, the_region_x, a_precision, the_nb_attempts, the_x2y, the_get_stats ) 
-
-    a_cost += calculate_optimal_number_threads( the_fun, a_seed_size, the_precision, the_nb_attempts )
-    if the_fun.number_threads() != an_old_number_threads:
-       the_x2y = {}
-       pass
-    
-    a_seed_size, a_cost2 = calculate_optimal_seed_size( the_fun, a_seed_size, the_region_x, the_precision, the_nb_attempts, the_x2y, the_get_stats )
-    #a_seed_size, a_cost2 = calculate_optimal_seed_size( the_fun, the_center_x, the_region_x, the_precision, the_nb_attempts, the_x2y, the_get_stats )  
-    
-    a_cost += a_cost2
-    return a_seed_size, a_cost
-
-
 #--------------------------------------------------------------------------------------
 def main() :
     #----------------------- Defining utility command-line interface -------------------------    
@@ -579,22 +396,6 @@ def main() :
 
 
     #----------------------- Definition of the command line arguments ------------------------
-    an_option_parser.add_option( "--region",
-                                 metavar = "< data center region : None, 'EU', ''( us-east ), 'us-west-1' or 'ap-southeast-1' >",
-                                 choices = [ 'None', 'EU', '', 'us-west-1', 'ap-southeast-1' ],
-                                 action = "store",
-                                 dest = "region",
-                                 help = "'%default', by default, for search \"best\" region. ",
-                                 default = None )    
-
-    an_option_parser.add_option( "--number-threads",
-                                 metavar = "< number of threads >",
-                                 type = "int",
-                                 action = "store",
-                                 dest = "number_threads",
-                                 help = "(%default, by default)",
-                                 default = 3 )
-
     an_option_parser.add_option( "--precision",
                                  metavar = "< algorithm precision, % >",
                                  type = "int",
@@ -629,14 +430,10 @@ def main() :
     
     amazon.security_options.add( an_option_parser )
 
-    common.options.add( an_option_parser )
-
     
     #------------------ Extracting and verifying command-line arguments ----------------------
     an_options, an_args = an_option_parser.parse_args()
 
-    common.options.extract( an_option_parser )
-
     AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.security_options.extract( an_option_parser )
 
     a_precision = an_options.precision
@@ -646,22 +443,16 @@ def main() :
     a_region_x = an_options.solution_window
 
     a_nb_attempts = an_options.number_mesurements
-    
-    a_data_region = an_options.region
-    
-    a_nb_threads = an_options.number_threads
-    
-    a_stats = {}
-    if a_data_region == None:
-       a_data_region, a_stats = search_best_region( a_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY )
-       pass
-    
-    an_engine = SeedSizeMesurement( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, a_data_region , a_nb_threads )
-    
+
+    from cloudflu.preferences import get
+    a_data_location = get( 'amazon.data_transfer.location' )
+
+    an_engine = SeedSizeMesurement( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, a_data_location )
+
     from cloudflu.common import Timer
     a_spent_time = Timer()
 
-    an_optimize_x, a_cost = entry_point( an_engine, a_center_x, a_region_x, a_precision, a_nb_attempts, a_stats, get_stats)
+    an_optimize_x, a_cost = entry_point( an_engine, a_center_x, a_region_x, a_precision, a_nb_attempts, get_stats )
 
     from preferences import resource_filename; an_rcfilename = resource_filename()
 
@@ -669,16 +460,13 @@ def main() :
 
     import os; os.system( "cp %s %s" % ( an_rcfilename, an_rcfilename_save ) )
 
-    import os; os.system( "perl -p -i -e 's/(socket_timeout =)\s*[.0-9]+/\\1 %3.2f/' %s" % 
+    import os; os.system( "perl -p -i -e 's/(socket_timeout =)\s*[0-9]+/\\1 %d/' %s" % 
                           ( an_engine.timeout(), an_rcfilename ) )
 
-    import os; os.system( "perl -p -i -e 's/(number_threads =)\s*[0-9]+/\\1 %d/' %s" % 
-                          ( an_engine.number_threads(), an_rcfilename ) )
-
     import os; os.system( "perl -p -i -e 's/(upload_seed_size =)\s*[0-9]+/\\1 %d/' %s" % 
                           ( an_optimize_x, an_rcfilename ) )
 
-    print_d( "a_spent_time = %s, sec\n" % a_spent_time )
+    print "a_spent_time = %s, sec\n" % a_spent_time
     pass
 
 
